Shivani Parekh has uploaded this change for review. ( https://gem5-review.googlesource.com/c/public/gem5/+/33536 )

Change subject: mem: Update master/slave and masterId in request.hh
......................................................................

mem: Update master/slave and masterId in request.hh

Change-Id: I4af248c241078a9cb6e22a9258c39856119a2622
---
M src/arch/arm/isa.cc
M src/arch/arm/table_walker.cc
M src/arch/arm/tracers/tarmac_parser.cc
M src/dev/x86/intdev.hh
M src/mem/cache/base.cc
M src/mem/cache/cache.cc
M src/mem/cache/cache_blk.hh
M src/mem/port.cc
M src/mem/port_proxy.cc
M src/mem/qos/policy_pf.cc
M src/mem/request.hh
M src/mem/ruby/system/CacheRecorder.cc
M src/mem/ruby/system/RubyPort.cc
M src/mem/ruby/system/RubyPort.hh
M src/mem/ruby/system/RubySystem.cc
M src/mem/translating_port_proxy.cc
M src/sim/system.cc
M src/sim/system.hh
18 files changed, 85 insertions(+), 83 deletions(-)



diff --git a/src/arch/arm/isa.cc b/src/arch/arm/isa.cc
index 6ef9fe3..b1ae705 100644
--- a/src/arch/arm/isa.cc
+++ b/src/arch/arm/isa.cc
@@ -2339,7 +2339,7 @@
warn_once("Doing AT (address translation) in functional mode! Fix Me!\n");

     auto req = std::make_shared<Request>(
-        val, 0, flags,  Request::funcMasterId,
+        val, 0, flags,  Request::funcUniqueId,
         tc->pcState().pc(), tc->contextId());

     Fault fault = getDTBPtr(tc)->translateFunctional(
@@ -2390,7 +2390,7 @@
warn_once("Doing AT (address translation) in functional mode! Fix Me!\n");

     auto req = std::make_shared<Request>(
-        val, 0, flags,  Request::funcMasterId,
+        val, 0, flags,  Request::funcUniqueId,
         tc->pcState().pc(), tc->contextId());

     Fault fault = getDTBPtr(tc)->translateFunctional(
diff --git a/src/arch/arm/table_walker.cc b/src/arch/arm/table_walker.cc
index e9502f8..e7893bc 100644
--- a/src/arch/arm/table_walker.cc
+++ b/src/arch/arm/table_walker.cc
@@ -55,7 +55,7 @@

 TableWalker::TableWalker(const Params *p)
     : ClockedObject(p),
-      stage2Mmu(NULL), port(NULL), _id(Request::invldMasterId),
+      stage2Mmu(NULL), port(NULL), _id(Request::invldUniqueId),
       isStage2(p->is_stage2), tlb(NULL),
       currState(NULL), pending(false),
       numSquashable(p->num_squash_per_cycle),
diff --git a/src/arch/arm/tracers/tarmac_parser.cc b/src/arch/arm/tracers/tarmac_parser.cc
index 9ed5bf4..4c1ce07 100644
--- a/src/arch/arm/tracers/tarmac_parser.cc
+++ b/src/arch/arm/tracers/tarmac_parser.cc
@@ -1287,7 +1287,7 @@
     ArmISA::TLB* dtb = static_cast<TLB*>(thread->getDTBPtr());

     req->setVirt(addr, size, flags, thread->pcState().instAddr(),
-                 Request::funcMasterId);
+                 Request::funcUniqueId);

     // Translate to physical address
     Fault fault = dtb->translateAtomic(req, thread, BaseTLB::Read);
diff --git a/src/dev/x86/intdev.hh b/src/dev/x86/intdev.hh
index a681a2e..9bf5fad 100644
--- a/src/dev/x86/intdev.hh
+++ b/src/dev/x86/intdev.hh
@@ -86,7 +86,7 @@
 buildIntPacket(Addr addr, T payload)
 {
     RequestPtr req = std::make_shared<Request>(
-        addr, sizeof(T), Request::UNCACHEABLE, Request::intMasterId);
+        addr, sizeof(T), Request::UNCACHEABLE, Request::intUniqueId);
     PacketPtr pkt = new Packet(req, MemCmd::WriteReq);
     pkt->allocate();
     pkt->setRaw<T>(payload);
diff --git a/src/mem/cache/base.cc b/src/mem/cache/base.cc
index 0187703..f92f87b 100644
--- a/src/mem/cache/base.cc
+++ b/src/mem/cache/base.cc
@@ -1488,10 +1488,10 @@
                   "Writeback from read-only cache");
     assert(blk && blk->isValid() && (blk->isDirty() || writebackClean));

-    stats.writebacks[Request::wbMasterId]++;
+    stats.writebacks[Request::wbUniqueId]++;

     RequestPtr req = std::make_shared<Request>(
-        regenerateBlkAddr(blk), blkSize, 0, Request::wbMasterId);
+        regenerateBlkAddr(blk), blkSize, 0, Request::wbUniqueId);

     if (blk->isSecure())
         req->setFlags(Request::SECURE);
@@ -1533,7 +1533,7 @@
 BaseCache::writecleanBlk(CacheBlk *blk, Request::Flags dest, PacketId id)
 {
     RequestPtr req = std::make_shared<Request>(
-        regenerateBlkAddr(blk), blkSize, 0, Request::wbMasterId);
+        regenerateBlkAddr(blk), blkSize, 0, Request::wbUniqueId);

     if (blk->isSecure()) {
         req->setFlags(Request::SECURE);
@@ -1606,7 +1606,7 @@
         assert(blk.isValid());

         RequestPtr request = std::make_shared<Request>(
-            regenerateBlkAddr(&blk), blkSize, 0, Request::funcMasterId);
+            regenerateBlkAddr(&blk), blkSize, 0, Request::funcUniqueId);

         request->taskId(blk.task_id);
         if (blk.isSecure()) {
diff --git a/src/mem/cache/cache.cc b/src/mem/cache/cache.cc
index 6fb6f11..58fc31a 100644
--- a/src/mem/cache/cache.cc
+++ b/src/mem/cache/cache.cc
@@ -912,7 +912,7 @@

     // Creating a zero sized write, a message to the snoop filter
     RequestPtr req = std::make_shared<Request>(
-        regenerateBlkAddr(blk), blkSize, 0, Request::wbMasterId);
+        regenerateBlkAddr(blk), blkSize, 0, Request::wbUniqueId);

     if (blk->isSecure())
         req->setFlags(Request::SECURE);
diff --git a/src/mem/cache/cache_blk.hh b/src/mem/cache/cache_blk.hh
index 427d7bb..3b94cf7 100644
--- a/src/mem/cache/cache_blk.hh
+++ b/src/mem/cache/cache_blk.hh
@@ -215,7 +215,7 @@
         status = 0;
         whenReady = MaxTick;
         refCount = 0;
-        srcMasterId = Request::invldMasterId;
+        srcMasterId = Request::invldUniqueId;
         lockList.clear();
     }

diff --git a/src/mem/port.cc b/src/mem/port.cc
index b901571..a9f5233 100644
--- a/src/mem/port.cc
+++ b/src/mem/port.cc
@@ -154,7 +154,7 @@
 RequestPort::printAddr(Addr a)
 {
     auto req = std::make_shared<Request>(
-        a, 1, 0, Request::funcMasterId);
+        a, 1, 0, Request::funcUniqueId);

     Packet pkt(req, MemCmd::PrintReq);
     Packet::PrintReqState prs(std::cerr);
diff --git a/src/mem/port_proxy.cc b/src/mem/port_proxy.cc
index b5fce19..fd6a94e 100644
--- a/src/mem/port_proxy.cc
+++ b/src/mem/port_proxy.cc
@@ -47,7 +47,7 @@
          gen.next()) {

         auto req = std::make_shared<Request>(
-            gen.addr(), gen.size(), flags, Request::funcMasterId);
+            gen.addr(), gen.size(), flags, Request::funcUniqueId);

         Packet pkt(req, MemCmd::ReadReq);
         pkt.dataStatic(static_cast<uint8_t *>(p));
@@ -64,7 +64,7 @@
          gen.next()) {

         auto req = std::make_shared<Request>(
-            gen.addr(), gen.size(), flags, Request::funcMasterId);
+            gen.addr(), gen.size(), flags, Request::funcUniqueId);

         Packet pkt(req, MemCmd::WriteReq);
         pkt.dataStaticConst(static_cast<const uint8_t *>(p));
diff --git a/src/mem/qos/policy_pf.cc b/src/mem/qos/policy_pf.cc
index a7aa103..5f4cfb7 100644
--- a/src/mem/qos/policy_pf.cc
+++ b/src/mem/qos/policy_pf.cc
@@ -59,7 +59,7 @@
 {
     MasterID id = memCtrl->system()->lookupMasterId(requestor);

-    assert(m_id != Request::invldMasterId);
+    assert(id != Request::invldUniqueId);

     // Setting the Initial score for the selected requestor.
     history.push_back(std::make_pair(id, score));
diff --git a/src/mem/ruby/system/CacheRecorder.cc b/src/mem/ruby/system/CacheRecorder.cc
index 1fc7bb8..a756573 100644
--- a/src/mem/ruby/system/CacheRecorder.cc
+++ b/src/mem/ruby/system/CacheRecorder.cc
@@ -87,7 +87,7 @@
         m_records_flushed++;
         auto req = std::make_shared<Request>(rec->m_data_address,
                                              m_block_size_bytes, 0,
-                                             Request::funcMasterId);
+                                             Request::funcUniqueId);
         MemCmd::Command requestType = MemCmd::FlushReq;
         Packet *pkt = new Packet(req, requestType);

@@ -119,18 +119,18 @@
                 requestType = MemCmd::ReadReq;
                 req = std::make_shared<Request>(
                     traceRecord->m_data_address + rec_bytes_read,
- RubySystem::getBlockSizeBytes(), 0, Request::funcMasterId); + RubySystem::getBlockSizeBytes(), 0, Request::funcUniqueId);
             }   else if (traceRecord->m_type == RubyRequestType_IFETCH) {
                 requestType = MemCmd::ReadReq;
                 req = std::make_shared<Request>(
                         traceRecord->m_data_address + rec_bytes_read,
                         RubySystem::getBlockSizeBytes(),
-                        Request::INST_FETCH, Request::funcMasterId);
+                        Request::INST_FETCH, Request::funcUniqueId);
             }   else {
                 requestType = MemCmd::WriteReq;
                 req = std::make_shared<Request>(
                     traceRecord->m_data_address + rec_bytes_read,
- RubySystem::getBlockSizeBytes(), 0, Request::funcMasterId); + RubySystem::getBlockSizeBytes(), 0, Request::funcUniqueId);
             }

             Packet *pkt = new Packet(req, requestType);
diff --git a/src/mem/ruby/system/RubyPort.hh b/src/mem/ruby/system/RubyPort.hh
index 2642540..23884ff 100644
--- a/src/mem/ruby/system/RubyPort.hh
+++ b/src/mem/ruby/system/RubyPort.hh
@@ -130,7 +130,8 @@
         Tick recvAtomic(PacketPtr pkt);

         void recvFunctional(PacketPtr pkt)
- { panic("recvFunctional should never be called on pio slave port!"); }
+        { panic("recvFunctional should never be called on pio response "
+                "port!"); }

         AddrRangeList getAddrRanges() const;
     };
diff --git a/src/mem/ruby/system/RubySystem.cc b/src/mem/ruby/system/RubySystem.cc
index 9507d25..7484bc0 100644
--- a/src/mem/ruby/system/RubySystem.cc
+++ b/src/mem/ruby/system/RubySystem.cc
@@ -123,8 +123,8 @@
     machineToNetwork.insert(std::make_pair(mach_id, network_id));
 }

-// This registers all master IDs in the system for functional reads. This
-// should be called in init() since master IDs are obtained in a SimObject's +// This registers all requestor IDs in the system for functional reads. This +// should be called in init() since requestor IDs are obtained in a SimObject's
 // constructor and there are functional reads/writes between init() and
 // startup().
 void
diff --git a/src/mem/translating_port_proxy.cc b/src/mem/translating_port_proxy.cc
index 8bb93cc..fc73514 100644
--- a/src/mem/translating_port_proxy.cc
+++ b/src/mem/translating_port_proxy.cc
@@ -83,7 +83,7 @@
          gen.next())
     {
         auto req = std::make_shared<Request>(
-                gen.addr(), gen.size(), flags, Request::funcMasterId, 0,
+                gen.addr(), gen.size(), flags, Request::funcUniqueId, 0,
                 _tc->contextId());

         if (!tryTLBs(req, BaseTLB::Read))
@@ -105,7 +105,7 @@
          gen.next())
     {
         auto req = std::make_shared<Request>(
-                gen.addr(), gen.size(), flags, Request::funcMasterId, 0,
+                gen.addr(), gen.size(), flags, Request::funcUniqueId, 0,
                 _tc->contextId());

         if (!tryTLBs(req, BaseTLB::Write))
@@ -125,7 +125,7 @@
          gen.next())
     {
         auto req = std::make_shared<Request>(
-                gen.addr(), gen.size(), flags, Request::funcMasterId, 0,
+                gen.addr(), gen.size(), flags, Request::funcUniqueId, 0,
                 _tc->contextId());

         if (!tryTLBs(req, BaseTLB::Write))
diff --git a/src/sim/system.cc b/src/sim/system.cc
index 971cc79..ac4ebed 100644
--- a/src/sim/system.cc
+++ b/src/sim/system.cc
@@ -249,11 +249,11 @@
     // Get the generic system master IDs
     MasterID tmp_id M5_VAR_USED;
     tmp_id = getMasterId(this, "writebacks");
-    assert(tmp_id == Request::wbMasterId);
+    assert(tmp_id == Request::wbUniqueId);
     tmp_id = getMasterId(this, "functional");
-    assert(tmp_id == Request::funcMasterId);
+    assert(tmp_id == Request::funcUniqueId);
     tmp_id = getMasterId(this, "interrupt");
-    assert(tmp_id == Request::intMasterId);
+    assert(tmp_id == Request::intUniqueId);

     // increment the number of running systems
     numSystemsRunning++;
@@ -556,14 +556,14 @@
 MasterID
 System::lookupMasterId(const SimObject* obj) const
 {
-    MasterID id = Request::invldMasterId;
+    MasterID id = Request::invldUniqueId;

     // number of occurrences of the SimObject pointer
     // in the master list.
     auto obj_number = 0;

-    for (int i = 0; i < masters.size(); i++) {
-        if (masters[i].obj == obj) {
+    for (int i = 0; i < requestors.size(); i++) {
+        if (requestors[i].obj == obj) {
             id = i;
             obj_number++;
         }
@@ -587,26 +587,26 @@
         }
     }

-    return Request::invldMasterId;
+    return Request::invldUniqueId;
 }

 MasterID
-System::getGlobalMasterId(const std::string& master_name)
+System::getGlobalMasterId(const std::string& _name)
 {
-    return _getMasterId(nullptr, master_name);
+    return _getMasterId(nullptr, _name);
 }

 MasterID
-System::getMasterId(const SimObject* master, std::string submaster)
+System::getMasterId(const SimObject* requestor, std::string subrequestor)
 {
-    auto master_name = leafMasterName(master, submaster);
-    return _getMasterId(master, master_name);
+    auto name = leafMasterName(requestor, subrequestor);
+    return _getMasterId(requestor, name);
 }

 MasterID
-System::_getMasterId(const SimObject* master, const std::string& master_name)
+System::_getMasterId(const SimObject* requestor, const std::string& _name)
 {
-    std::string name = stripSystemName(master_name);
+    std::string name = stripSystemName(_name);

     // CPUs in switch_cpus ask for ids again after switching
     for (int i = 0; i < requestors.size(); i++) {
@@ -625,31 +625,31 @@
     }

     // Generate a new MasterID incrementally
-    MasterID master_id = masters.size();
+    MasterID _id = requestors.size();

     // Append the new Master metadata to the group of system Masters.
-    masters.emplace_back(master, name, master_id);
+    requestors.emplace_back(requestor, name, _id);

-    return masters.back().masterId;
+    return requestors.back()._id;
 }

 std::string
-System::leafMasterName(const SimObject* master, const std::string& submaster) +System::leafMasterName(const SimObject* requestor, const std::string& subrequestor)
 {
-    if (submaster.empty()) {
-        return master->name();
+    if (subrequestor.empty()) {
+        return requestor->name();
     } else {
         // Get the full master name by appending the submaster name to
         // the root SimObject master name
-        return master->name() + "." + submaster;
+        return requestor->name() + "." + subrequestor;
     }
 }

 std::string
-System::getMasterName(MasterID master_id)
+System::getMasterName(MasterID unique_id)
 {
-    if (master_id >= masters.size())
-        fatal("Invalid master_id passed to getMasterName()\n");
+    if (unique_id >= requestors.size())
+        fatal("Invalid id passed to getMasterName()\n");

     const auto& requestor_info = requestors[unique_id];
     return requestor_info.req_name;
diff --git a/src/mem/request.hh b/src/mem/request.hh
index 7b324dc..5b541e0 100644
--- a/src/mem/request.hh
+++ b/src/mem/request.hh
@@ -196,23 +196,23 @@
     static const FlagsType STORE_NO_DATA = CACHE_BLOCK_ZERO |
         CLEAN | INVALIDATE;

     /** Master Ids that are statically allocated
      * @{*/
     enum : MasterID {
-        /** This master id is used for writeback requests by the caches */
-        wbMasterId = 0,
+        /** This unique id is used for writeback requests by the caches */
+        wbUniqueId = 0,
         /**
          * This master id is used for functional requests that
          * don't come from a particular device
          */
-        funcMasterId = 1,
-        /** This master id is used for message signaled interrupts */
-        intMasterId = 2,
+        funcUniqueId = 1,
+        /** This unique id is used for message signaled interrupts */
+        intUniqueId = 2,
         /**
          * Invalid master id for assertion checking only. It is
          * invalid behavior to ever send this id as part of a request.
          */
-        invldMasterId = std::numeric_limits<MasterID>::max()
+        invldUniqueId = std::numeric_limits<MasterID>::max()
     };
     /** @} */

@@ -302,7 +302,7 @@
     /** The requestor ID which is unique in the system for all ports
      * that are capable of issuing a transaction
      */
-    MasterID _masterId = invldMasterId;
+    MasterID _requestorId = invldUniqueId;

     /** Flag structure for the request. */
     Flags _flags;
@@ -376,25 +376,25 @@
      * just physical address, size, flags, and timestamp (to curTick()).
      * These fields are adequate to perform a request.
      */
-    Request(Addr paddr, unsigned size, Flags flags, MasterID mid) :
-        _paddr(paddr), _size(size), _masterId(mid), _time(curTick())
+    Request(Addr paddr, unsigned size, Flags flags, MasterID id) :
+        _paddr(paddr), _size(size), _requestorId(id), _time(curTick())
     {
         _flags.set(flags);
         privateFlags.set(VALID_PADDR|VALID_SIZE);
     }

     Request(Addr vaddr, unsigned size, Flags flags,
-            MasterID mid, Addr pc, ContextID cid,
+            MasterID id, Addr pc, ContextID cid,
             AtomicOpFunctorPtr atomic_op=nullptr)
     {
-        setVirt(vaddr, size, flags, mid, pc, std::move(atomic_op));
+        setVirt(vaddr, size, flags, id, pc, std::move(atomic_op));
         setContext(cid);
     }

     Request(const Request& other)
         : _paddr(other._paddr), _size(other._size),
           _byteEnable(other._byteEnable),
-          _masterId(other._masterId),
+          _requestorId(other._requestorId),
           _flags(other._flags),
           _cacheCoherenceFlags(other._cacheCoherenceFlags),
           privateFlags(other.privateFlags),
@@ -442,12 +442,12 @@
      * allocated Request object.
      */
     void
-    setVirt(Addr vaddr, unsigned size, Flags flags, MasterID mid, Addr pc,
+    setVirt(Addr vaddr, unsigned size, Flags flags, MasterID id, Addr pc,
             AtomicOpFunctorPtr amo_op=nullptr)
     {
         _vaddr = vaddr;
         _size = size;
-        _masterId = mid;
+        _requestorId = id;
         _pc = pc;
         _time = curTick();

@@ -656,7 +656,7 @@
     MasterID
     masterId() const
     {
-        return _masterId;
+        return _requestorId;
     }

     uint32_t
@@ -196,23 +196,23 @@
         CLEAN | INVALIDATE;

-    /** Master Ids that are statically allocated
+    /** Unique Ids that are statically allocated
      * @{*/
     enum : MasterID {
@@ -196,23 +196,23 @@
         /**
-         * This master id is used for functional requests that
+         * This unique id is used for functional requests that
          * don't come from a particular device
          */
@@ -196,23 +196,23 @@
         /**
-         * Invalid master id for assertion checking only. It is
+         * Invalid unique id for assertion checking only. It is
          * invalid behavior to ever send this id as part of a request.
          */
diff --git a/src/mem/ruby/system/RubyPort.cc b/src/mem/ruby/system/RubyPort.cc
index fa13cf4..94d5946 100644
--- a/src/mem/ruby/system/RubyPort.cc
+++ b/src/mem/ruby/system/RubyPort.cc
@@ -126,14 +126,14 @@
     : QueuedMasterPort(_name, _port, reqQueue, snoopRespQueue),
       reqQueue(*_port, *this), snoopRespQueue(*_port, *this)
 {
-    DPRINTF(RubyPort, "Created master pioport on sequencer %s\n", _name);
+    DPRINTF(RubyPort, "Created request pioport on sequencer %s\n", _name);
 }

 RubyPort::PioSlavePort::PioSlavePort(const std::string &_name,
                            RubyPort *_port)
     : QueuedSlavePort(_name, _port, queue), queue(*_port, *this)
 {
-    DPRINTF(RubyPort, "Created slave pioport on sequencer %s\n", _name);
+    DPRINTF(RubyPort, "Created response pioport on sequencer %s\n", _name);
 }

 RubyPort::MemMasterPort::MemMasterPort(const std::string &_name,
@@ -141,7 +141,7 @@
     : QueuedMasterPort(_name, _port, reqQueue, snoopRespQueue),
       reqQueue(*_port, *this), snoopRespQueue(*_port, *this)
 {
- DPRINTF(RubyPort, "Created master memport on ruby sequencer %s\n", _name); + DPRINTF(RubyPort, "Created request memport on ruby sequencer %s\n", _name);
 }

RubyPort::MemSlavePort::MemSlavePort(const std::string &_name, RubyPort *_port,
@@ -151,7 +151,8 @@
       access_backing_store(_access_backing_store),
       no_retry_on_stall(_no_retry_on_stall)
 {
- DPRINTF(RubyPort, "Created slave memport on ruby sequencer %s\n", _name);
+    DPRINTF(RubyPort, "Created response memport on ruby sequencer %s\n",
+            _name);
 }

 bool
@@ -585,7 +586,7 @@
 AddrRangeList
 RubyPort::PioSlavePort::getAddrRanges() const
 {
-    // at the moment the assumption is that the master does not care
+    // at the moment the assumption is that the requestor does not care
     AddrRangeList ranges;
     RubyPort *ruby_port = static_cast<RubyPort *>(&owner);

@@ -612,10 +613,10 @@
     DPRINTF(RubyPort, "Sending invalidations.\n");
     // Allocate the invalidate request and packet on the stack, as it is
     // assumed they will not be modified or deleted by receivers.
     // TODO: should this really be using funcMasterId?
     auto request = std::make_shared<Request>(
         address, RubySystem::getBlockSizeBytes(), 0,
-        Request::funcMasterId);
+        Request::funcUniqueId);

// Use a single packet to signal all snooping ports of the invalidation.
     // This assumes that snooping ports do NOT modify the packet/request
@@ -612,10 +613,10 @@
     // Allocate the invalidate request and packet on the stack, as it is
     // assumed they will not be modified or deleted by receivers.
-    // TODO: should this really be using funcMasterId?
+    // TODO: should this really be using funcUniqueId?
     auto request = std::make_shared<Request>(
         address, RubySystem::getBlockSizeBytes(), 0,
diff --git a/src/sim/system.hh b/src/sim/system.hh
index 8e2c472..52530f5 100644
--- a/src/sim/system.hh
+++ b/src/sim/system.hh
@@ -427,7 +427,7 @@
      * It's used to uniquely id any master in the system by name for things
      * like cache statistics.
      */
-    std::vector<MasterInfo> masters;
+    std::vector<MasterInfo> requestors;

     ThermalModel * thermalModel;

@@ -444,26 +444,26 @@
* that intend to issues requests into the memory system must request an id
      * in the init() phase of startup. All master ids must be fixed by the
* regStats() phase that immediately precedes it. This allows objects in
      * the memory system to understand how many masters may exist and
* appropriately name the bins of their per-master stats before the stats
      * are finalized.
      *
      * Registers a MasterID:
      * This method takes two parameters, one of which is optional.
      * The first one is the master object, and it is compulsory; in case
      * a object has multiple (sub)masters, a second parameter must be
      * provided and it contains the name of the submaster. The method will
      * create a master's name by concatenating the SimObject name with the
      * eventual submaster string, separated by a dot.
      *
      * As an example:
- * For a cpu having two masters: a data master and an instruction master, + * For a cpu having two requestors: a data master and an instruction master,
      * the method must be called twice:
      *
      * instMasterId = getMasterId(cpu, "inst");
      * dataMasterId = getMasterId(cpu, "data");
      *
      * and the masters' names will be:
      * - "cpu.inst"
      * - "cpu.data"
      *
@@ -491,18 +491,18 @@

     /**
      * Looks up the MasterID for a given SimObject
-     * returns an invalid MasterID (invldMasterId) if not found.
+     * returns an invalid MasterID (invldUniqueId) if not found.
      */
     MasterID lookupMasterId(const SimObject* obj) const;

     /**
      * Looks up the MasterID for a given object name string
-     * returns an invalid MasterID (invldMasterId) if not found.
+     * returns an invalid MasterID (invldUniqueId) if not found.
      */
     MasterID lookupMasterId(const std::string& name) const;

-    /** Get the number of masters registered in the system */
-    MasterID maxMasters() { return masters.size(); }
+    /** Get the number of requestors registered in the system */
+    MasterID maxMasters() { return requestors.size(); }

   protected:
     /** helper function for getMasterId */
@@ -444,26 +444,26 @@
      * in the init() phase of startup. All master ids must be fixed by the
* regStats() phase that immediately precedes it. This allows objects in
-     * the memory system to understand how many masters may exist and
+     * the memory system to understand how many requestors may exist and
* appropriately name the bins of their per-master stats before the stats
      * are finalized.
@@ -444,26 +444,26 @@
      * This method takes two parameters, one of which is optional.
      * The first one is the master object, and it is compulsory; in case
-     * a object has multiple (sub)masters, a second parameter must be
+     * a object has multiple (sub)requestors, a second parameter must be
      * provided and it contains the name of the submaster. The method will
      * create a master's name by concatenating the SimObject name with the
@@ -444,26 +444,26 @@
      * dataMasterId = getMasterId(cpu, "data");
      *
-     * and the masters' names will be:
+     * and the requestors' names will be:
      * - "cpu.inst"
      * - "cpu.data"

--
To view, visit https://gem5-review.googlesource.com/c/public/gem5/+/33536
To unsubscribe, or for help writing mail filters, visit https://gem5-review.googlesource.com/settings

Gerrit-Project: public/gem5
Gerrit-Branch: develop
Gerrit-Change-Id: I4af248c241078a9cb6e22a9258c39856119a2622
Gerrit-Change-Number: 33536
Gerrit-PatchSet: 1
Gerrit-Owner: Shivani Parekh <[email protected]>
Gerrit-MessageType: newchange
_______________________________________________
gem5-dev mailing list -- [email protected]
To unsubscribe send an email to [email protected]
%(web_page_url)slistinfo%(cgiext)s/%(_internal_name)s

Reply via email to